src/hg/inc/web.h 1.43

1.43 2009/06/03 04:30:19 markd
don't dumps stacks on find errors; doing stack dump in abort handler rather than warn handler simplifies
Index: src/hg/inc/web.h
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/inc/web.h,v
retrieving revision 1.42
retrieving revision 1.43
diff -b -B -U 4 -r1.42 -r1.43
--- src/hg/inc/web.h	3 Jun 2009 00:34:09 -0000	1.42
+++ src/hg/inc/web.h	3 Jun 2009 04:30:19 -0000	1.43
@@ -257,12 +257,15 @@
 
 boolean webDumpStackEnabled(void);
 /* is browser.dumpStack enabled?  */
 
-void webPushDumpStackHandler(void);
-/* push the stack dump handler on the stack if it's enabled.  This should be pushed
+void webDumpStackDisallow(void);
+/* prevent any dumping of the stack */
+
+void webDumpStackPushAbortHandler(void);
+/* push the stack dump abort handler on the stack if it's enabled.  This should be pushed
  * after the warn handle that will do the actual reporting */
 
-void webPopDumpStackHandler(void);
-/* pop the stack dump handler from the stack if it's enabled */
+void webDumpStackPopAbortHandler(void);
+/* pop the stack dump abort handler from the stack if it's enabled */
 
 #endif /* WEB_H */